"""
synopsis:
    Functions for used from Elixir called through Erlport.
functions:
    mean -- Compute the mean of a column in a dask dataframe loaded from CSV.
"""

from __future__ import print_function
import sys
import os
import numpy as np
import dask.dataframe as dd
from erlport.erlterms import Atom


def mean(index, csv_file_name, column_name, verbose):
    """Compute the mean of a column in a dask dataframe loaded from CSV.
    """
    csv_file_name = csv_file_name.decode()
    column_name = column_name.decode()
    file_name = os.path.join(
        os.path.abspath('.'), 'pylib', csv_file_name)
    if verbose:
        print('py version: {}'.format(sys.version))
        print("idx: {}  ds: {}  cn: {}".format(
            index, file_name, column_name))
    if not os.path.exists(file_name):
        msg = 'csv file "{}" not found'.format(file_name)
        if verbose:
            print(msg)
        return Atom(b'not_found'), msg
    df1 = dd.read_csv(file_name, blocksize=8000000)
    if column_name not in df1.columns:
        cols = [nm for nm in df1.columns if not nm.startswith('Unnamed:')]
        msg = 'column "{}" not in dataframe.  available columns: {}'.format(
            column_name, cols)
        if verbose:
            print(msg)
        return Atom(b'invalid_column'), msg
    mean = df1[column_name].mean().compute()
    value = "{:.4f}".format(mean)
    if verbose:
        print('mean: {}'.format(value))
    return Atom(b'ok'), (
        "{:3d}".format(index), csv_file_name, column_name, value)


def test():
    mean(1, b'tmp5.csv', b'A', True)


if __name__ == '__main__':
    #import ipdb; ipdb.set_trace()
    test()
